/* Gnofract -- a little fractal generator-browser program
 * Copyright (C) 1999  2000 Aurelien Alleaume
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "fract.h"

int calc_num = 0;		/* we will know if another calc has been started */
int calculating = FALSE;
extern GtkWidget *drawing_area;
extern GtkWidget *appbar1;
extern GtkWidget *app;
extern GtkWidget *propertybox;
struct param_image

 param_current = { NULL, NULL, ".", ".", 400, 300, -3.0, -2.0, 3.0, 2.0, 4, 100, 0, 0,0},
 param_defaut = {NULL, NULL, ".", ".", 400, 300, -3.0, -2.0, 3.0, 2.0, 4, 100, 0, 0, 0};

double zoom_plus = 2, zoom_moins = 2;

gboolean quit_cb(GtkWidget * widget, GdkEvent * event, gpointer user_data)
{
	/* FIX ME : we should stop any calc running */
	if (param_current.cmap != NULL)
		free(param_current.cmap);	/* free colormap */
	if (param_current.tmp_img != NULL)
		free(param_current.tmp_img);  /* free img */
	gtk_main_quit();
	return FALSE;
}


void new_image_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gtk_widget_set_usize(drawing_area, param_current.Xres, param_current.Yres);
	param_current.xmin = param_defaut.xmin;
	param_current.ymin = param_defaut.ymin;
	param_current.xmax = param_defaut.xmax;
	param_current.ymax = param_defaut.ymax;
	param_current.fractal_type = param_defaut.fractal_type;
	init_cmap(&param_current);
	if (param_current.tmp_img == NULL)
		realloc_memory(&param_current);
	strcpy(param_current.formula_file_name, ".");
	refresh_image();
}


void save_image_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gtk_widget_show(create_save_image());
}


void save_param_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gtk_widget_show(create_save_param());
}


void load_param_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gtk_widget_show(create_load_param());
}

void load_cmap_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gtk_widget_show(create_load_cmap());
}

void load_formula_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gtk_widget_show(create_load_formula());
}

void render_to_disk_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gtk_widget_show(create_render_to_disk());
}


void preferences_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	if (propertybox == NULL)
		gtk_widget_show(create_propertybox());
}


void about_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gtk_widget_show(create_about());
}

void help_content_cb(GtkMenuItem * menuitem, gpointer user_data)
{
	gnome_ok_dialog(_
			("Functions:\n Left button : let you draw a rectangle wich will be the next image. Release the button when ok.\n	Middle button click : zoom in.\n	Right button click : zoom out."));
}

void save_image_ok_cb(GtkButton * button, gpointer user_data)
{
	char *nom;
	GdkImlibImage *img_save;
	gnome_appbar_push((GnomeAppBar *) appbar1, _(" saving image ... "));
	nom = gnome_file_entry_get_full_path((GnomeFileEntry *)
					     user_data, FALSE);
	img_save = gdk_imlib_create_image_from_data((unsigned char *)
						    param_current.tmp_img, NULL,
						    param_current.Xres, param_current.Yres);
	gdk_imlib_render(img_save, param_current.Xres, param_current.Yres);
	gdk_imlib_save_image(img_save, nom, NULL);
	gnome_appbar_pop((GnomeAppBar *) appbar1);

}


void save_param_ok_cb(GtkButton * button, gpointer user_data)
{
	char *nom;
	FILE *file;
	nom = gnome_file_entry_get_full_path((GnomeFileEntry *)
					     user_data, FALSE);
	if ((file = fopen(nom, "wb")) == NULL) {
		gtk_widget_show(gnome_warning_dialog(_("Not saved : I can't create the file  !")));
		return;
	}
	fprintf(file, "%.50f\n", param_current.xmin);
	fprintf(file, "%.50f\n", param_current.ymin);
	fprintf(file, "%.50f\n", param_current.xmax);
	fprintf(file, "%.50f\n", param_current.ymax);
	fprintf(file, "%d\n", param_current.nbit_max);
	fprintf(file, "%d\n", param_current.eject_val);
	fprintf(file, "%d\n", param_current.fractal_type);
	fprintf(file, "%d\n", param_current.cmap_flag);
	fprintf(file, "%s\n", param_current.cmap_file_name);
	fprintf(file, "%s\n", param_current.formula_file_name);
	fclose(file);
}


void load_param_ok_cb(GtkButton * button, gpointer user_data)
{

	char *nom;
	FILE *file;
	nom = gnome_file_entry_get_full_path((GnomeFileEntry *)
					     user_data, FALSE);
	if ((file = fopen(nom, "rb")) == NULL) {
		gtk_widget_show(gnome_warning_dialog
				(_("Formula not loaded : I can't open the file  !")));
		return;
	}
	fscanf(file, "%lf", &param_current.xmin);
	fscanf(file, "%lf", &param_current.ymin);
	fscanf(file, "%lf", &param_current.xmax);
	fscanf(file, "%lf", &param_current.ymax);
	fscanf(file, "%d", &param_current.nbit_max);
	fscanf(file, "%d", &param_current.eject_val);
	fscanf(file, "%d", &param_current.fractal_type);
	fscanf(file, "%d", &param_current.cmap_flag);
	fscanf(file, "%s", (char *) &param_current.cmap_file_name);
	fscanf(file, "%s", (char *) &param_current.formula_file_name);
	fclose(file);
	if (param_current.fractal_type != 0)
		load_formula(&param_current);
	if (param_current.cmap_flag != 0)
		load_cmap(&param_current);
	else
		init_cmap(&param_current);
	refresh_image();
}

void load_cmap_ok_cb(GtkButton * button, gpointer user_data)
{

	char *nom;
	nom = gnome_file_entry_get_full_path((GnomeFileEntry *)
					     user_data, FALSE);
	strncpy((char *) &param_current.cmap_file_name, nom, 256);
	if (load_cmap(&param_current))
		refresh_image();
}

void load_formula_ok_cb(GtkButton * button, gpointer user_data)
{

	char *nom;
	nom = gnome_file_entry_get_full_path((GnomeFileEntry *) user_data, FALSE);
	strncpy((char *) &param_current.formula_file_name, nom, 256);
	reset_coord();
	if (load_formula(&param_current))
		refresh_image();
}

void render_to_disk_ok_cb(GtkButton * button, gpointer user_data)
{
	struct param_image param_rtd = param_current;
	char *nom;
	GdkImlibImage *img_save;
	gtk_widget_unmap(GTK_WIDGET(button));	/* user won't click twice */
	nom = gnome_file_entry_get_full_path((GnomeFileEntry *)
					     lookup_widget(user_data, "fileentry_rtd_nom"), FALSE);
	param_rtd.Xres = gnome_number_entry_get_number((GnomeNumberEntry *)
						       lookup_widget(user_data,
								     "numberentry_rtd_xres"));
	param_rtd.Yres = gnome_number_entry_get_number((GnomeNumberEntry *)
						       lookup_widget(user_data,
								     "numberentry_rtd_yres"));
	param_rtd.aa_profondeur = gnome_number_entry_get_number((GnomeNumberEntry *)
								lookup_widget(user_data,
									      "numberentry_rtd_aa"));

	if (calculating == TRUE) {
		gtk_widget_show(gnome_warning_dialog(_("NOT rendered : a calc is running  !")));
		return;
	}
	calculating = TRUE;
	param_rtd.tmp_img =
	    (struct rgb *) malloc((param_rtd.Xres) * (param_rtd.Yres) * sizeof(struct rgb));
	calc(&param_rtd, calc_num);
	calculating = FALSE;
	gnome_appbar_push((GnomeAppBar *) appbar1, _("Saving ..."));
	img_save =
	    gdk_imlib_create_image_from_data((unsigned char *) param_rtd.tmp_img, NULL,
					     param_rtd.Xres, param_rtd.Yres);
	gdk_imlib_render(img_save, param_rtd.Xres, param_rtd.Yres);
	gdk_imlib_save_image(img_save, nom, NULL);

	gnome_appbar_pop((GnomeAppBar *) appbar1);
	free(param_rtd.tmp_img);
	param_rtd.tmp_img = NULL;

}


void render_to_disk_annuler_cb(GtkButton * button, gpointer user_data)
{
	calc_num++;		/* calc will be cancelled */
	gnome_appbar_push((GnomeAppBar *) appbar1, _("Aborted"));
	gtk_stuff_fin();

}


void propertybox_apply(GnomePropertyBox * gnomepropertybox, gint arg1, gpointer user_data)
{
	int Xres_new, Yres_new;

	if (arg1 != -1)
		return;

	Xres_new = abs(gnome_number_entry_get_number((GnomeNumberEntry *)
						     lookup_widget((GtkWidget *)
								   gnomepropertybox,
								   "numberentry_image_width")));

	Yres_new = abs(gnome_number_entry_get_number((GnomeNumberEntry *)
						     lookup_widget((GtkWidget *)
								   gnomepropertybox,
								   "numberentry_image_height")));

	param_current.nbit_max = abs(gnome_number_entry_get_number((GnomeNumberEntry *)
								   lookup_widget((GtkWidget *)
										 gnomepropertybox,
										 "numberentry_nb_iteration_max")));

	param_current.eject_val = abs(gnome_number_entry_get_number((GnomeNumberEntry *)
								    lookup_widget((GtkWidget *)
										  gnomepropertybox,
										  "numberentry_eject_val")));

	param_current.xmin = gnome_number_entry_get_number((GnomeNumberEntry *)
							   lookup_widget((GtkWidget *)
									 gnomepropertybox,
									 "numberentry_xmin"));

	param_current.ymax = gnome_number_entry_get_number((GnomeNumberEntry *)
							   lookup_widget((GtkWidget *)
									 gnomepropertybox,
									 "numberentry_ymax"));

	param_current.xmax = gnome_number_entry_get_number((GnomeNumberEntry *)
							   lookup_widget((GtkWidget *)
									 gnomepropertybox,
									 "numberentry_xmax"));

	param_current.ymin = gnome_number_entry_get_number((GnomeNumberEntry *)
							   lookup_widget((GtkWidget *)
									 gnomepropertybox,
									 "numberentry_ymin"));

	param_current.aa_profondeur = gnome_number_entry_get_number((GnomeNumberEntry *)
								    lookup_widget((GtkWidget *)
										  gnomepropertybox,
										  "numberentry_aa"));

	zoom_plus = gnome_number_entry_get_number((GnomeNumberEntry *)
						  lookup_widget((GtkWidget *)
								gnomepropertybox,
								"numberentry_zoom_plus"));

	zoom_moins = gnome_number_entry_get_number((GnomeNumberEntry *)
						   lookup_widget((GtkWidget *)
								 gnomepropertybox,
								 "numberentry_zoom_moins"));




	if ((param_current.Xres != Xres_new)
	    || (param_current.Yres != Yres_new)) {
		param_current.Xres = Xres_new;
		param_current.Yres = Yres_new;
		gtk_widget_set_usize(drawing_area, param_current.Xres, param_current.Yres);
		realloc_memory(&param_current);
	}

	refresh_image();

}


void propertybox_help(GnomePropertyBox * gnomepropertybox, gint arg1, gpointer user_data)
{



}


void propertybox_destroy(void)
{
	propertybox = NULL;
}


void mouse_event(GtkWidget * widget, GdkEvent * event, gpointer data)
{

	static int x, y;	/* coordonnees */
	static int x1, y1, x2, y2;
	int new_x, new_y;
	static int distance;
	switch (event->type) {

	case GDK_BUTTON_PRESS:

		if (event->button.button == 1) {
			x = event->button.x;
			y = event->button.y;
			distance = 0;
		} else if (event->button.button == 2) {
			double deltax, deltay, centerx, centery, largeur_new, hauteur_new;
			x = event->button.x;
			y = event->button.y;
			deltax = (param_current.xmax - param_current.xmin) / param_current.Xres;
			deltay = (param_current.ymax - param_current.ymin) / param_current.Yres;
			centerx = param_current.xmin + x * deltax;
			centery = param_current.ymin + y * deltay;
			largeur_new = (param_current.xmax - param_current.xmin) / zoom_plus;
			hauteur_new = (param_current.ymax - param_current.ymin) / zoom_plus;
			param_current.xmin = centerx - largeur_new / 2;
			param_current.ymin = centery - hauteur_new / 2;
			param_current.xmax = centerx + largeur_new / 2;
			param_current.ymax = centery + hauteur_new / 2;
			deltax = (param_current.xmax - param_current.xmin) / param_current.Xres;
			/* si precision maximale dpasse : erreur */
			if (deltax < 1.5e-16)
				gtk_widget_show(gnome_warning_dialog
						(_
						 ("Sorry, max precision was reached, the image will become horrible !")));
			refresh_image();

		} else if (event->button.button == 3) {
			double deltax, deltay, centerx, centery, largeur_new, hauteur_new;
			x = event->button.x;
			y = event->button.y;
			deltax = (param_current.xmax - param_current.xmin) / param_current.Xres;
			deltay = (param_current.ymax - param_current.ymin) / param_current.Yres;
			centerx = param_current.xmin + x * deltax;
			centery = param_current.ymin + y * deltay;
			largeur_new = (param_current.xmax - param_current.xmin) * zoom_moins;
			hauteur_new = (param_current.ymax - param_current.ymin) * zoom_moins;
			param_current.xmin = centerx - largeur_new / 2;
			param_current.ymin = centery - hauteur_new / 2;
			param_current.xmax = centerx + largeur_new / 2;
			param_current.ymax = centery + hauteur_new / 2;
			refresh_image();
		}
		break;



	case GDK_MOTION_NOTIFY:
		{
			double ratio;
			gdk_window_get_pointer(widget->window, &new_x, &new_y, NULL);	/*get pointer coord */
			distance = sqrt((x - new_x) * (x - new_x) + (y - new_y) * (y - new_y));
			ratio = (double) param_current.Xres / (double) param_current.Yres;
			x1 = x - distance * ratio;
			x2 = x + distance * ratio;
			y1 = y - distance;
			y2 = y + distance;
			redraw_image_zone(widget, 0, 0, param_current.Xres,
					  param_current.Yres, param_current.Xres,
					  param_current.tmp_img);
			gdk_draw_rectangle(widget->window, widget->style->white_gc, 0, x1, y1,
					   (gint) (x2 - x1), (gint) (y2 - y1));
		}
		break;
	case GDK_BUTTON_RELEASE:
		if (event->button.button == 1) {
			double deltax, deltay;
			if (distance < 2)
				break;	/* user probably did a mistake thus we do nothing */
			deltax = (param_current.xmax - param_current.xmin) / param_current.Xres;
			deltay = (param_current.ymax - param_current.ymin) / param_current.Yres;
			param_current.xmin += x1 * deltax;
			param_current.ymin += y1 * deltay;
			param_current.xmax -= (param_current.Xres - x2) * deltax;
			param_current.ymax -= (param_current.Yres - y2) * deltay;
			deltax = (param_current.xmax - param_current.xmin) / param_current.Xres;
			/*si precision maximale dpasse : erreur */
			if (deltax < 1.5e-16)
				gtk_widget_show(gnome_warning_dialog
						(_
						 ("Sorry, max precision was reached, the image will become horrible !")));
			refresh_image();

		}
		break;
	default:
		break;

	}


}

int expose_event(GtkWidget * widget, GdkEventExpose * event)
{
	if (param_current.tmp_img != NULL 
)
		redraw_image_zone(widget, event->area.x, event->area.y,
				  event->area.width, event->area.height, param_current.Xres,
				  param_current.tmp_img);
	return 1;
}
