/* Gnofract -- a little fractal generator-browser program
 * Copyright (C) 1999 2000  Aurelien Alleaume
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "fract.h"

GtkWidget *drawing_area;
GtkWidget *appbar1;
GtkWidget *app;
GtkWidget *propertybox = NULL;

extern struct param_image param_current;
extern double zoom_plus, zoom_moins;

static GnomeUIInfo file1_menu_uiinfo[] = {
	{
	 GNOME_APP_UI_ITEM, N_("Reset  image to default"),
	 NULL,
	 new_image_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_NEW,
	 0, 0, NULL},
	{
	 GNOME_APP_UI_ITEM, N_("Save image"),
	 NULL,
	 save_image_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_SAVE,
	 0, 0, NULL},
	{
	 GNOME_APP_UI_ITEM, N_("Save param"),
	 NULL,
	 save_param_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_SAVE_AS,
	 0, 0, NULL},
	{
	 GNOME_APP_UI_ITEM, N_("Load param"),
	 NULL,
	 load_param_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_OPEN,
	 0, 0, NULL},
	{
	 GNOME_APP_UI_ITEM, N_("Render to disk"),
	 NULL,
	 render_to_disk_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_EXEC,
	 0, 0, NULL},
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_MENU_EXIT_ITEM(quit_cb, NULL),
	GNOMEUIINFO_END
};

static GnomeUIInfo param_tres1_menu_uiinfo[] = {
	GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cb, NULL),
	{
	 GNOME_APP_UI_ITEM, N_("Load colormap"),
	 NULL,
	 load_cmap_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_OPEN,
	 0, 0, NULL},
	{
	 GNOME_APP_UI_ITEM, N_("Load formula"),
	 NULL,
	 load_formula_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_OPEN,
	 0, 0, NULL},
	{
	 GNOME_APP_UI_ITEM, N_("Reset location"),
	 NULL,
	 reset_coord, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_NEW,
	 0, 0, NULL},
	{
	 GNOME_APP_UI_ITEM, N_("Update image"),
	 NULL,
	 refresh_image, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_EXEC,
	 0, 0, NULL},
	GNOMEUIINFO_END
};

static GnomeUIInfo help1_menu_uiinfo[] = {
	GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb,
				    NULL),
	{
	 GNOME_APP_UI_ITEM,
	 N_("Mouse functions..."),
	 NULL,
	 help_content_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_STOCK,
	 GNOME_STOCK_MENU_BOOK_OPEN,
	 0, 0, NULL},
	GNOMEUIINFO_END
};

static GnomeUIInfo menubar1_uiinfo[] = {
	GNOMEUIINFO_MENU_FILE_TREE(file1_menu_uiinfo),
	GNOMEUIINFO_MENU_SETTINGS_TREE(param_tres1_menu_uiinfo),
	GNOMEUIINFO_MENU_HELP_TREE(help1_menu_uiinfo),
	GNOMEUIINFO_END
};

GtkWidget *create_app()
{
	GtkWidget *dock1;
	GtkWidget *vbox1;

	app = gnome_app_new("Gnofract", _("Gnofract"));
	gtk_widget_set_name(app, "app");
	gtk_object_set_data(GTK_OBJECT(app), "app", app);
	gtk_window_set_policy(GTK_WINDOW(app), FALSE, FALSE, TRUE);

	dock1 = GNOME_APP(app)->dock;
	gtk_widget_set_name(dock1, "dock1");
	gtk_widget_ref(dock1);
	gtk_object_set_data_full(GTK_OBJECT(app), "dock1", dock1,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(dock1);

	gnome_app_create_menus(GNOME_APP(app), menubar1_uiinfo);

	gtk_widget_set_name(menubar1_uiinfo[0].widget, "file1");
	gtk_widget_ref(menubar1_uiinfo[0].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "file1",
				 menubar1_uiinfo[0].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(file1_menu_uiinfo[0].widget, "new_image1");
	gtk_widget_ref(file1_menu_uiinfo[0].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "new_image1",
				 file1_menu_uiinfo[0].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(file1_menu_uiinfo[1].widget, "save_image1");
	gtk_widget_ref(file1_menu_uiinfo[1].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "save_image1",
				 file1_menu_uiinfo[1].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(file1_menu_uiinfo[2].widget, "save_param1");
	gtk_widget_ref(file1_menu_uiinfo[2].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "save_param1",
				 file1_menu_uiinfo[2].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(file1_menu_uiinfo[3].widget, "load_param1");
	gtk_widget_ref(file1_menu_uiinfo[3].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "load_param1",
				 file1_menu_uiinfo[3].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(file1_menu_uiinfo[4].widget, "render_to_disk1");
	gtk_widget_ref(file1_menu_uiinfo[4].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "render_to_disk1",
				 file1_menu_uiinfo[4].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(file1_menu_uiinfo[5].widget, "separator2");
	gtk_widget_ref(file1_menu_uiinfo[5].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "separator2",
				 file1_menu_uiinfo[5].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(file1_menu_uiinfo[6].widget, "quitter1");
	gtk_widget_ref(file1_menu_uiinfo[6].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "quitter1",
				 file1_menu_uiinfo[6].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(menubar1_uiinfo[1].widget, "param_tres1");
	gtk_widget_ref(menubar1_uiinfo[1].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "param_tres1",
				 menubar1_uiinfo[1].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(param_tres1_menu_uiinfo[0].widget, "pr_f_rences1");
	gtk_widget_ref(param_tres1_menu_uiinfo[0].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "pr_f_rences1",
				 param_tres1_menu_uiinfo[0].widget,
				 (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(menubar1_uiinfo[2].widget, "help1");
	gtk_widget_ref(menubar1_uiinfo[2].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "help1",
				 menubar1_uiinfo[2].widget, (GtkDestroyNotify) gtk_widget_unref);

	gtk_widget_set_name(help1_menu_uiinfo[0].widget, "about1");
	gtk_widget_ref(help1_menu_uiinfo[0].widget);
	gtk_object_set_data_full(GTK_OBJECT(app), "about1",
				 help1_menu_uiinfo[0].widget, (GtkDestroyNotify) gtk_widget_unref);

	vbox1 = gtk_vbox_new(FALSE, 0);
	gtk_widget_set_name(vbox1, "vbox1");
	gtk_widget_ref(vbox1);
	gtk_object_set_data_full(GTK_OBJECT(app), "vbox1", vbox1,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(vbox1);
	gnome_app_set_contents(GNOME_APP(app), vbox1);

	gtk_widget_push_visual(gdk_rgb_get_visual());
	gtk_widget_push_colormap(gdk_rgb_get_cmap());
	drawing_area = gtk_drawing_area_new();
	gtk_widget_pop_colormap();
	gtk_widget_pop_visual();
	gtk_widget_set_usize(drawing_area, param_current.Xres, param_current.Yres);
	gtk_box_pack_start(GTK_BOX(vbox1), drawing_area, TRUE, TRUE, 0);
	gtk_widget_set_events(drawing_area,
			      GDK_EXPOSURE_MASK |
			      GDK_BUTTON_PRESS_MASK |
			      GDK_BUTTON_RELEASE_MASK | GDK_BUTTON1_MOTION_MASK |
			      GDK_POINTER_MOTION_HINT_MASK);

	gtk_signal_connect(GTK_OBJECT(drawing_area), "expose_event", (GtkSignalFunc) expose_event,
			   NULL);

	gtk_signal_connect(GTK_OBJECT(drawing_area), "button_press_event",
			   (GtkSignalFunc) mouse_event, NULL);

	gtk_signal_connect(GTK_OBJECT(drawing_area), "motion_notify_event",
			   (GtkSignalFunc) mouse_event, NULL);

	gtk_signal_connect(GTK_OBJECT(drawing_area), "button_release_event",
			   (GtkSignalFunc) mouse_event, NULL);

	gtk_widget_set_name(drawing_area, "drawing_area");
	gtk_widget_ref(drawing_area);
	gtk_object_set_data_full(GTK_OBJECT(app), "drawing_area", drawing_area, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(drawing_area);

	appbar1 = gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_NEVER);
	gtk_widget_set_name(appbar1, "appbar1");
	gtk_widget_ref(appbar1);
	gtk_object_set_data_full(GTK_OBJECT(app), "appbar1", appbar1,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(appbar1);
	gnome_app_set_statusbar(GNOME_APP(app), appbar1);

	gtk_signal_connect(GTK_OBJECT(app), "delete_event", GTK_SIGNAL_FUNC(quit_cb), NULL);
	gtk_signal_connect(GTK_OBJECT(app), "destroy_event", GTK_SIGNAL_FUNC(quit_cb), NULL);

	return app;
}

GtkWidget *create_about()
{
	const gchar *authors[] = {
		"Aurlien Alleaume",
		NULL
	};
	GtkWidget *about;

	about =
	    gnome_about_new("Gnofract", VERSION, "", authors,
			    _("web :  http://www.multimania.com/mason"), NULL);
	gtk_widget_set_name(about, "about");
	gtk_object_set_data(GTK_OBJECT(about), "about", about);
	gtk_window_set_modal(GTK_WINDOW(about), TRUE);

	return about;
}

GtkWidget *create_save_image()
{
	GtkWidget *save_image;
	GtkWidget *dialog_vbox1;
	GtkWidget *fileentry_save_image;
	GtkWidget *combo_entry_save_image;
	GtkWidget *dialog_action_area1;
	GtkWidget *button_ok;
	GtkWidget *button_annuler;

	save_image = gnome_dialog_new(_("Save image"), NULL);
	gtk_widget_set_name(save_image, "save_image");
	gtk_object_set_data(GTK_OBJECT(save_image), "save_image", save_image);
	GTK_WINDOW(save_image)->type = GTK_WINDOW_DIALOG;
	gtk_window_set_modal(GTK_WINDOW(save_image), TRUE);
	gtk_window_set_policy(GTK_WINDOW(save_image), FALSE, FALSE, TRUE);

	dialog_vbox1 = GNOME_DIALOG(save_image)->vbox;
	gtk_widget_set_name(dialog_vbox1, "dialog_vbox1");
	gtk_object_set_data(GTK_OBJECT(save_image), "dialog_vbox1", dialog_vbox1);
	gtk_widget_show(dialog_vbox1);

	fileentry_save_image = gnome_file_entry_new("fileentry_save_image_id", NULL);
	gtk_widget_set_name(fileentry_save_image, "fileentry_save_image");
	gtk_widget_ref(fileentry_save_image);
	gtk_object_set_data_full(GTK_OBJECT(save_image),
				 "fileentry_save_image", fileentry_save_image,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(fileentry_save_image);
	gtk_box_pack_start(GTK_BOX(dialog_vbox1), fileentry_save_image, FALSE, FALSE, 0);
	gnome_file_entry_set_modal(GNOME_FILE_ENTRY(fileentry_save_image), TRUE);

	combo_entry_save_image = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(fileentry_save_image));
	gtk_widget_set_name(combo_entry_save_image, "combo_entry_save_image");
	gtk_widget_ref(combo_entry_save_image);
	gtk_object_set_data_full(GTK_OBJECT(save_image),
				 "combo_entry_save_image", combo_entry_save_image,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_save_image);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_save_image), _("image.png"));

	dialog_action_area1 = GNOME_DIALOG(save_image)->action_area;
	gtk_widget_set_name(dialog_action_area1, "dialog_action_area1");
	gtk_object_set_data(GTK_OBJECT(save_image), "dialog_action_area1", dialog_action_area1);
	gtk_widget_show(dialog_action_area1);
	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
	gtk_button_box_set_spacing(GTK_BUTTON_BOX(dialog_action_area1), 8);

	gnome_dialog_append_button(GNOME_DIALOG(save_image), GNOME_STOCK_BUTTON_OK);
	button_ok = g_list_last(GNOME_DIALOG(save_image)->buttons)->data;
	gtk_widget_set_name(button_ok, "button_ok");
	gtk_widget_ref(button_ok);
	gtk_object_set_data_full(GTK_OBJECT(save_image), "button_ok", button_ok, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(button_ok);
	GTK_WIDGET_SET_FLAGS(button_ok, GTK_CAN_DEFAULT);

	gnome_dialog_append_button(GNOME_DIALOG(save_image), GNOME_STOCK_BUTTON_CANCEL);
	button_annuler = g_list_last(GNOME_DIALOG(save_image)->buttons)->data;
	gtk_widget_set_name(button_annuler, "button_annuler");
	gtk_widget_ref(button_annuler);
	gtk_object_set_data_full(GTK_OBJECT(save_image), "button_annuler",
				 button_annuler, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(button_annuler);
	GTK_WIDGET_SET_FLAGS(button_annuler, GTK_CAN_DEFAULT);

	gtk_signal_connect(GTK_OBJECT(button_ok), "clicked", GTK_SIGNAL_FUNC(save_image_ok_cb),
			   fileentry_save_image);
	gtk_signal_connect_object_after(GTK_OBJECT(button_ok), "clicked",
					GTK_SIGNAL_FUNC(gtk_widget_destroy),
					GTK_OBJECT(save_image));
	gtk_signal_connect_object(GTK_OBJECT(button_annuler), "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(save_image));

	return save_image;
}

GtkWidget *create_save_param()
{
	GtkWidget *save_param;
	GtkWidget *dialog_vbox2;
	GtkWidget *fileentry_save_param;
	GtkWidget *combo_entry_save_param;
	GtkWidget *dialog_action_area2;
	GtkWidget *button_ok;
	GtkWidget *button_annuler;

	save_param = gnome_dialog_new(_("save param"), NULL);
	gtk_widget_set_name(save_param, "save_param");
	gtk_object_set_data(GTK_OBJECT(save_param), "save_param", save_param);
	GTK_WINDOW(save_param)->type = GTK_WINDOW_DIALOG;
	gtk_window_set_modal(GTK_WINDOW(save_param), TRUE);
	gtk_window_set_policy(GTK_WINDOW(save_param), FALSE, FALSE, TRUE);

	dialog_vbox2 = GNOME_DIALOG(save_param)->vbox;
	gtk_widget_set_name(dialog_vbox2, "dialog_vbox2");
	gtk_object_set_data(GTK_OBJECT(save_param), "dialog_vbox2", dialog_vbox2);
	gtk_widget_show(dialog_vbox2);

	fileentry_save_param = gnome_file_entry_new("fileentry_save_param_id", NULL);
	gtk_widget_set_name(fileentry_save_param, "fileentry_save_param");
	gtk_widget_ref(fileentry_save_param);
	gtk_object_set_data_full(GTK_OBJECT(save_param),
				 "fileentry_save_param", fileentry_save_param,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(fileentry_save_param);
	gtk_box_pack_start(GTK_BOX(dialog_vbox2), fileentry_save_param, FALSE, FALSE, 0);
	gnome_file_entry_set_modal(GNOME_FILE_ENTRY(fileentry_save_param), TRUE);

	combo_entry_save_param = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(fileentry_save_param));
	gtk_widget_set_name(combo_entry_save_param, "combo_entry_save_param");
	gtk_widget_ref(combo_entry_save_param);
	gtk_object_set_data_full(GTK_OBJECT(save_param),
				 "combo_entry_save_param", combo_entry_save_param,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_save_param);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_save_param), _("param.fct"));

	dialog_action_area2 = GNOME_DIALOG(save_param)->action_area;
	gtk_widget_set_name(dialog_action_area2, "dialog_action_area2");
	gtk_object_set_data(GTK_OBJECT(save_param), "dialog_action_area2", dialog_action_area2);
	gtk_widget_show(dialog_action_area2);
	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area2), GTK_BUTTONBOX_END);
	gtk_button_box_set_spacing(GTK_BUTTON_BOX(dialog_action_area2), 8);

	gnome_dialog_append_button(GNOME_DIALOG(save_param), GNOME_STOCK_BUTTON_OK);
	button_ok = g_list_last(GNOME_DIALOG(save_param)->buttons)->data;
	gtk_widget_set_name(button_ok, "button_ok");
	gtk_widget_ref(button_ok);
	gtk_object_set_data_full(GTK_OBJECT(save_param), "button_ok", button_ok, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(button_ok);
	GTK_WIDGET_SET_FLAGS(button_ok, GTK_CAN_DEFAULT);

	gnome_dialog_append_button(GNOME_DIALOG(save_param), GNOME_STOCK_BUTTON_CANCEL);
	button_annuler = g_list_last(GNOME_DIALOG(save_param)->buttons)->data;
	gtk_widget_set_name(button_annuler, "button_annuler");
	gtk_widget_ref(button_annuler);
	gtk_object_set_data_full(GTK_OBJECT(save_param), "button_annuler",
				 button_annuler, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(button_annuler);
	GTK_WIDGET_SET_FLAGS(button_annuler, GTK_CAN_DEFAULT);

	gtk_signal_connect(GTK_OBJECT(button_ok), "clicked", GTK_SIGNAL_FUNC(save_param_ok_cb),
			   fileentry_save_param);
	gtk_signal_connect_object_after(GTK_OBJECT(button_ok), "clicked",
					GTK_SIGNAL_FUNC(gtk_widget_destroy),
					GTK_OBJECT(save_param));
	gtk_signal_connect_object(GTK_OBJECT(button_annuler), "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(save_param));


	return save_param;
}

GtkWidget *create_load_param()
{
	GtkWidget *load_param;
	GtkWidget *dialog_vbox3;
	GtkWidget *fileentry_load_param;
	GtkWidget *combo_entry_load_param;
	GtkWidget *dialog_action_area3;
	GtkWidget *button_ok;
	GtkWidget *button_annuler;

	load_param = gnome_dialog_new(_("load param"), NULL);
	gtk_widget_set_name(load_param, "load_param");
	gtk_object_set_data(GTK_OBJECT(load_param), "load_param", load_param);
	GTK_WINDOW(load_param)->type = GTK_WINDOW_DIALOG;
	gtk_window_set_modal(GTK_WINDOW(load_param), TRUE);
	gtk_window_set_policy(GTK_WINDOW(load_param), FALSE, FALSE, TRUE);

	dialog_vbox3 = GNOME_DIALOG(load_param)->vbox;
	gtk_widget_set_name(dialog_vbox3, "dialog_vbox3");
	gtk_object_set_data(GTK_OBJECT(load_param), "dialog_vbox3", dialog_vbox3);
	gtk_widget_show(dialog_vbox3);

	fileentry_load_param = gnome_file_entry_new("fileentry_load_param_id", NULL);
	gtk_widget_set_name(fileentry_load_param, "fileentry_load_param");
	gtk_widget_ref(fileentry_load_param);
	gtk_object_set_data_full(GTK_OBJECT(load_param),
				 "fileentry_load_param", fileentry_load_param,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(fileentry_load_param);
	gtk_box_pack_start(GTK_BOX(dialog_vbox3), fileentry_load_param, FALSE, FALSE, 0);

	combo_entry_load_param = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(fileentry_load_param));
	gtk_widget_set_name(combo_entry_load_param, "combo_entry_load_param");
	gtk_widget_ref(combo_entry_load_param);
	gtk_object_set_data_full(GTK_OBJECT(load_param),
				 "combo_entry_load_param", combo_entry_load_param,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_load_param);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_load_param), _("param.fct"));

	dialog_action_area3 = GNOME_DIALOG(load_param)->action_area;
	gtk_widget_set_name(dialog_action_area3, "dialog_action_area3");
	gtk_object_set_data(GTK_OBJECT(load_param), "dialog_action_area3", dialog_action_area3);
	gtk_widget_show(dialog_action_area3);
	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area3), GTK_BUTTONBOX_END);
	gtk_button_box_set_spacing(GTK_BUTTON_BOX(dialog_action_area3), 8);

	gnome_dialog_append_button(GNOME_DIALOG(load_param), GNOME_STOCK_BUTTON_OK);
	button_ok = g_list_last(GNOME_DIALOG(load_param)->buttons)->data;
	gtk_widget_set_name(button_ok, "button_ok");
	gtk_widget_ref(button_ok);
	gtk_object_set_data_full(GTK_OBJECT(load_param), "button_ok", button_ok, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(button_ok);
	GTK_WIDGET_SET_FLAGS(button_ok, GTK_CAN_DEFAULT);

	gnome_dialog_append_button(GNOME_DIALOG(load_param), GNOME_STOCK_BUTTON_CANCEL);
	button_annuler = g_list_last(GNOME_DIALOG(load_param)->buttons)->data;
	gtk_widget_set_name(button_annuler, "button_annuler");
	gtk_widget_ref(button_annuler);
	gtk_object_set_data_full(GTK_OBJECT(load_param), "button_annuler",
				 button_annuler, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(button_annuler);
	GTK_WIDGET_SET_FLAGS(button_annuler, GTK_CAN_DEFAULT);

	/*we hide the dialog box wich had the focus during update. And now we can act on the app widget  during the update. */

	gtk_signal_connect_object(GTK_OBJECT(button_ok), "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(load_param));
	gtk_signal_connect_after(GTK_OBJECT(button_ok), "clicked",
				 GTK_SIGNAL_FUNC(load_param_ok_cb), fileentry_load_param);
	gtk_signal_connect_object_after(GTK_OBJECT(button_ok), "clicked",
					GTK_SIGNAL_FUNC(gtk_widget_destroy),
					GTK_OBJECT(load_param));
	gtk_signal_connect_object(GTK_OBJECT(button_annuler), "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(load_param));

	gtk_widget_set_usize(load_param, 500, 85);

	return load_param;
}

GtkWidget *create_load_cmap()
{
	GtkWidget *load_cmap;
	GtkWidget *dialog_vbox3;
	GtkWidget *fileentry_load_cmap;
	GtkWidget *combo_entry_load_cmap;
	GtkWidget *dialog_action_area3;
	GtkWidget *button_ok;
	GtkWidget *button_annuler;

	load_cmap = gnome_dialog_new(_("load cmap"), NULL);
	gtk_widget_set_name(load_cmap, "load_cmap");
	gtk_object_set_data(GTK_OBJECT(load_cmap), "load_cmap", load_cmap);
	GTK_WINDOW(load_cmap)->type = GTK_WINDOW_DIALOG;
	gtk_window_set_modal(GTK_WINDOW(load_cmap), TRUE);
	gtk_window_set_policy(GTK_WINDOW(load_cmap), FALSE, FALSE, TRUE);

	dialog_vbox3 = GNOME_DIALOG(load_cmap)->vbox;
	gtk_widget_set_name(dialog_vbox3, "dialog_vbox3");
	gtk_object_set_data(GTK_OBJECT(load_cmap), "dialog_vbox3", dialog_vbox3);
	gtk_widget_show(dialog_vbox3);

	fileentry_load_cmap = gnome_file_entry_new("fileentry_load_cmap_id", NULL);
	gtk_widget_set_name(fileentry_load_cmap, "fileentry_load_cmap");
	gtk_widget_ref(fileentry_load_cmap);
	gtk_object_set_data_full(GTK_OBJECT(load_cmap),
				 "fileentry_load_cmap", fileentry_load_cmap,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(fileentry_load_cmap);
	gtk_box_pack_start(GTK_BOX(dialog_vbox3), fileentry_load_cmap, FALSE, FALSE, 0);

	combo_entry_load_cmap = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(fileentry_load_cmap));
	gtk_widget_set_name(combo_entry_load_cmap, "combo_entry_load_cmap");
	gtk_widget_ref(combo_entry_load_cmap);
	gtk_object_set_data_full(GTK_OBJECT(load_cmap),
				 "combo_entry_load_cmap", combo_entry_load_cmap,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_load_cmap);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_load_cmap), param_current.cmap_file_name);

	dialog_action_area3 = GNOME_DIALOG(load_cmap)->action_area;
	gtk_widget_set_name(dialog_action_area3, "dialog_action_area3");
	gtk_object_set_data(GTK_OBJECT(load_cmap), "dialog_action_area3", dialog_action_area3);
	gtk_widget_show(dialog_action_area3);
	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area3), GTK_BUTTONBOX_END);
	gtk_button_box_set_spacing(GTK_BUTTON_BOX(dialog_action_area3), 8);

	gnome_dialog_append_button(GNOME_DIALOG(load_cmap), GNOME_STOCK_BUTTON_OK);
	button_ok = g_list_last(GNOME_DIALOG(load_cmap)->buttons)->data;
	gtk_widget_set_name(button_ok, "button_ok");
	gtk_widget_ref(button_ok);
	gtk_object_set_data_full(GTK_OBJECT(load_cmap), "button_ok", button_ok, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(button_ok);
	GTK_WIDGET_SET_FLAGS(button_ok, GTK_CAN_DEFAULT);

	gnome_dialog_append_button(GNOME_DIALOG(load_cmap), GNOME_STOCK_BUTTON_CANCEL);
	button_annuler = g_list_last(GNOME_DIALOG(load_cmap)->buttons)->data;
	gtk_widget_set_name(button_annuler, "button_annuler");
	gtk_widget_ref(button_annuler);
	gtk_object_set_data_full(GTK_OBJECT(load_cmap), "button_annuler",
				 button_annuler, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(button_annuler);
	GTK_WIDGET_SET_FLAGS(button_annuler, GTK_CAN_DEFAULT);


	/*we hide the dialog box wich had the focus during update. And now we can act on the app widget  during the update. */

	gtk_signal_connect_object(GTK_OBJECT(button_ok), "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(load_cmap));
	gtk_signal_connect_after(GTK_OBJECT(button_ok), "clicked",
				 GTK_SIGNAL_FUNC(load_cmap_ok_cb), fileentry_load_cmap);
	gtk_signal_connect_object_after(GTK_OBJECT(button_ok), "clicked",
					GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(load_cmap));
	gtk_signal_connect_object(GTK_OBJECT(button_annuler), "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(load_cmap));

	gtk_widget_set_usize(load_cmap, 500, 85);

	return load_cmap;
}


GtkWidget *create_load_formula()
{
	GtkWidget *load_formula;
	GtkWidget *dialog_vbox3;
	GtkWidget *fileentry_load_formula;
	GtkWidget *combo_entry_load_formula;
	GtkWidget *dialog_action_area3;
	GtkWidget *button_ok;
	GtkWidget *button_annuler;

	load_formula = gnome_dialog_new(_("load formula"), NULL);
	gtk_widget_set_name(load_formula, "load_formula");
	gtk_object_set_data(GTK_OBJECT(load_formula), "load_formula", load_formula);
	GTK_WINDOW(load_formula)->type = GTK_WINDOW_DIALOG;
	gtk_window_set_modal(GTK_WINDOW(load_formula), TRUE);
	gtk_window_set_policy(GTK_WINDOW(load_formula), FALSE, FALSE, TRUE);

	dialog_vbox3 = GNOME_DIALOG(load_formula)->vbox;
	gtk_widget_set_name(dialog_vbox3, "dialog_vbox3");
	gtk_object_set_data(GTK_OBJECT(load_formula), "dialog_vbox3", dialog_vbox3);
	gtk_widget_show(dialog_vbox3);

	fileentry_load_formula = gnome_file_entry_new("fileentry_load_formula_id", NULL);
	gtk_widget_set_name(fileentry_load_formula, "fileentry_load_formula");
	gtk_widget_ref(fileentry_load_formula);
	gtk_object_set_data_full(GTK_OBJECT(load_formula),
				 "fileentry_load_formula", fileentry_load_formula,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(fileentry_load_formula);
	gtk_box_pack_start(GTK_BOX(dialog_vbox3), fileentry_load_formula, FALSE, FALSE, 0);

	combo_entry_load_formula =
	    gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(fileentry_load_formula));
	gtk_widget_set_name(combo_entry_load_formula, "combo_entry_load_formula");
	gtk_widget_ref(combo_entry_load_formula);
	gtk_object_set_data_full(GTK_OBJECT(load_formula),
				 "combo_entry_load_formula",
				 combo_entry_load_formula, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_load_formula);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_load_formula), param_current.formula_file_name);

	dialog_action_area3 = GNOME_DIALOG(load_formula)->action_area;
	gtk_widget_set_name(dialog_action_area3, "dialog_action_area3");
	gtk_object_set_data(GTK_OBJECT(load_formula), "dialog_action_area3", dialog_action_area3);
	gtk_widget_show(dialog_action_area3);
	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area3), GTK_BUTTONBOX_END);
	gtk_button_box_set_spacing(GTK_BUTTON_BOX(dialog_action_area3), 8);

	gnome_dialog_append_button(GNOME_DIALOG(load_formula), GNOME_STOCK_BUTTON_OK);
	button_ok = g_list_last(GNOME_DIALOG(load_formula)->buttons)->data;
	gtk_widget_set_name(button_ok, "button_ok");
	gtk_widget_ref(button_ok);
	gtk_object_set_data_full(GTK_OBJECT(load_formula), "button_ok", button_ok,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(button_ok);
	GTK_WIDGET_SET_FLAGS(button_ok, GTK_CAN_DEFAULT);

	gnome_dialog_append_button(GNOME_DIALOG(load_formula), GNOME_STOCK_BUTTON_CANCEL);
	button_annuler = g_list_last(GNOME_DIALOG(load_formula)->buttons)->data;
	gtk_widget_set_name(button_annuler, "button_annuler");
	gtk_widget_ref(button_annuler);
	gtk_object_set_data_full(GTK_OBJECT(load_formula),
				 "button_annuler", button_annuler,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(button_annuler);
	GTK_WIDGET_SET_FLAGS(button_annuler, GTK_CAN_DEFAULT);


	/*we hide the dialog box wich had the focus during update. And now we can act on the app widget  during the update. */

	gtk_signal_connect_object(GTK_OBJECT(button_ok), "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(load_formula));
	gtk_signal_connect_after(GTK_OBJECT(button_ok), "clicked",
				 GTK_SIGNAL_FUNC(load_formula_ok_cb), fileentry_load_formula);
	gtk_signal_connect_object_after(GTK_OBJECT(button_ok), "clicked",
					GTK_SIGNAL_FUNC(gtk_widget_destroy),
					GTK_OBJECT(load_formula));
	gtk_signal_connect_object(GTK_OBJECT(button_annuler), "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(load_formula));

	gtk_widget_set_usize(load_formula, 500, 85);

	return load_formula;
}




GtkWidget *create_render_to_disk()
{
	GtkWidget *render_to_disk;
	GtkWidget *dialog_vbox4;
	GtkWidget *table1;
	GtkWidget *label1;
	GtkWidget *label2;
	GtkWidget *label3;
	GtkWidget *label20;
	GtkWidget *label21;
	GtkWidget *label22;
	GtkWidget *numberentry_rtd_xres;
	GtkWidget *combo_entry_rtd_xres;
	GtkWidget *numberentry_rtd_yres;
	GtkWidget *combo_entry_rtd_yres;
	GtkWidget *fileentry_rtd_nom;
	GtkWidget *combo_entry_rtd_nom;
	GtkWidget *numberentry_rtd_aa;
	GtkWidget *combo_entry_rtd_aa;
	GtkWidget *dialog_action_area4;
	GtkWidget *button_ok;
	GtkWidget *button_annuler;
	GtkTooltips *tooltips;

	tooltips = gtk_tooltips_new();

	render_to_disk = gnome_dialog_new(_("render to disk"), NULL);
	gtk_widget_set_name(render_to_disk, "render_to_disk");
	gtk_object_set_data(GTK_OBJECT(render_to_disk), "render_to_disk", render_to_disk);
	gtk_container_set_border_width(GTK_CONTAINER(render_to_disk), 1);
	GTK_WINDOW(render_to_disk)->type = GTK_WINDOW_DIALOG;

	gtk_window_set_modal(GTK_WINDOW(render_to_disk), TRUE);
	gtk_window_set_policy(GTK_WINDOW(render_to_disk), FALSE, FALSE, TRUE);
	dialog_vbox4 = GNOME_DIALOG(render_to_disk)->vbox;
	gtk_widget_set_name(dialog_vbox4, "dialog_vbox4");
	gtk_object_set_data(GTK_OBJECT(render_to_disk), "dialog_vbox4", dialog_vbox4);
	gtk_widget_show(dialog_vbox4);

	table1 = gtk_table_new(5, 2, FALSE);
	gtk_widget_set_name(table1, "table1");
	gtk_widget_ref(table1);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk), "table1", table1, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(table1);
	gtk_box_pack_start(GTK_BOX(dialog_vbox4), table1, TRUE, TRUE, 0);

	label1 = gtk_label_new(_("Xres : "));
	gtk_widget_set_name(label1, "label1");
	gtk_widget_ref(label1);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk), "label1", label1, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label1);
	gtk_table_attach(GTK_TABLE(table1), label1, 0, 1, 0, 1, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	label2 = gtk_label_new(_("Yres : "));
	gtk_widget_set_name(label2, "label2");
	gtk_widget_ref(label2);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk), "label2", label2, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label2);
	gtk_table_attach(GTK_TABLE(table1), label2, 0, 1, 1, 2, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	label3 = gtk_label_new(_("name : "));
	gtk_widget_set_name(label3, "label3");
	gtk_widget_ref(label3);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk), "label3", label3, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label3);
	gtk_table_attach(GTK_TABLE(table1), label3, 0, 1, 2, 3, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	numberentry_rtd_xres = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_rtd_xres, "numberentry_rtd_xres");
	gtk_widget_ref(numberentry_rtd_xres);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "numberentry_rtd_xres", numberentry_rtd_xres,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_rtd_xres);
	gtk_table_attach(GTK_TABLE(table1), numberentry_rtd_xres, 1, 2, 0, 1, (GtkAttachOptions)
			 (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
	GTK_WIDGET_SET_FLAGS(numberentry_rtd_xres, GTK_CAN_FOCUS);
	GTK_WIDGET_SET_FLAGS(numberentry_rtd_xres, GTK_CAN_DEFAULT);

	combo_entry_rtd_xres =
	    gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_rtd_xres));
	gtk_widget_set_name(combo_entry_rtd_xres, "combo_entry_rtd_xres");
	gtk_widget_ref(combo_entry_rtd_xres);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "combo_entry_rtd_xres", combo_entry_rtd_xres,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_rtd_xres);
	gtk_tooltips_set_tip(tooltips, combo_entry_rtd_xres, _("width"), NULL);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_rtd_xres), _("800"));

	numberentry_rtd_yres = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_rtd_yres, "numberentry_rtd_yres");
	gtk_widget_ref(numberentry_rtd_yres);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "numberentry_rtd_yres", numberentry_rtd_yres,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_rtd_yres);
	gtk_table_attach(GTK_TABLE(table1), numberentry_rtd_yres, 1, 2, 1, 2, (GtkAttachOptions)
			 (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_rtd_yres =
	    gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_rtd_yres));
	gtk_widget_set_name(combo_entry_rtd_yres, "combo_entry_rtd_yres");
	gtk_widget_ref(combo_entry_rtd_yres);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "combo_entry_rtd_yres", combo_entry_rtd_yres,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_rtd_yres);
	gtk_tooltips_set_tip(tooltips, combo_entry_rtd_yres, _("height"), NULL);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_rtd_yres), _("600"));

	fileentry_rtd_nom = gnome_file_entry_new(NULL, NULL);
	gtk_widget_set_name(fileentry_rtd_nom, "fileentry_rtd_nom");
	gtk_widget_ref(fileentry_rtd_nom);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "fileentry_rtd_nom", fileentry_rtd_nom,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(fileentry_rtd_nom);
	gtk_table_attach(GTK_TABLE(table1), fileentry_rtd_nom, 1, 2, 2, 3,
			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_rtd_nom = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(fileentry_rtd_nom));
	gtk_widget_set_name(combo_entry_rtd_nom, "combo_entry_rtd_nom");
	gtk_widget_ref(combo_entry_rtd_nom);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "combo_entry_rtd_nom", combo_entry_rtd_nom,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_rtd_nom);
	gtk_tooltips_set_tip(tooltips, combo_entry_rtd_nom, _("name.type"), NULL);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_rtd_nom), _("image.png"));

	label20 = gtk_label_new(_("Antialiasing : "));
	gtk_widget_set_name(label20, "label20");
	gtk_widget_ref(label20);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk), "label20", label20, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label20);
	gtk_table_attach(GTK_TABLE(table1), label20, 0, 1, 4, 5, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	numberentry_rtd_aa = gnome_number_entry_new("rtd_aa", NULL);
	gtk_widget_set_name(numberentry_rtd_aa, "numberentry_rtd_aa");
	gtk_widget_ref(numberentry_rtd_aa);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "numberentry_rtd_aa", numberentry_rtd_aa,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_rtd_aa);
	gtk_table_attach(GTK_TABLE(table1), numberentry_rtd_aa, 1, 2, 4, 5,
			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_rtd_aa = gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_rtd_aa));
	gtk_widget_set_name(combo_entry_rtd_aa, "combo_entry_rtd_aa");
	gtk_widget_ref(combo_entry_rtd_aa);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "combo_entry_rtd_aa", combo_entry_rtd_aa,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_rtd_aa);
	gtk_tooltips_set_tip(tooltips, combo_entry_rtd_aa,
			     _
			     ("0 or 1 : none.\n  > 10 : you are crazy.\n 3 seems to be a good choice if you don't have a powerfull computer"),
			     NULL);
	gtk_entry_set_text(GTK_ENTRY(combo_entry_rtd_aa), _("0"));

	label21 = gtk_label_new("");
	gtk_widget_set_name(label21, "label21");
	gtk_widget_ref(label21);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk), "label21", label21, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label21);
	gtk_table_attach(GTK_TABLE(table1), label21, 0, 1, 3, 4, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	label22 = gtk_label_new("");
	gtk_widget_set_name(label22, "label22");
	gtk_widget_ref(label22);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk), "label22", label22, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label22);
	gtk_table_attach(GTK_TABLE(table1), label22, 1, 2, 3, 4, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	dialog_action_area4 = GNOME_DIALOG(render_to_disk)->action_area;
	gtk_widget_set_name(dialog_action_area4, "dialog_action_area4");
	gtk_object_set_data(GTK_OBJECT(render_to_disk), "dialog_action_area4", dialog_action_area4);
	gtk_widget_show(dialog_action_area4);
	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area4), GTK_BUTTONBOX_END);
	gtk_button_box_set_spacing(GTK_BUTTON_BOX(dialog_action_area4), 8);

	gnome_dialog_append_button(GNOME_DIALOG(render_to_disk), GNOME_STOCK_BUTTON_OK);
	button_ok = g_list_last(GNOME_DIALOG(render_to_disk)->buttons)->data;
	gtk_widget_set_name(button_ok, "button_ok");
	gtk_widget_ref(button_ok);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk), "button_ok",
				 button_ok, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(button_ok);
	GTK_WIDGET_SET_FLAGS(button_ok, GTK_CAN_DEFAULT);

	gnome_dialog_append_button(GNOME_DIALOG(render_to_disk), GNOME_STOCK_BUTTON_CANCEL);
	button_annuler = g_list_last(GNOME_DIALOG(render_to_disk)->buttons)->data;
	gtk_widget_set_name(button_annuler, "button_annuler");
	gtk_widget_ref(button_annuler);
	gtk_object_set_data_full(GTK_OBJECT(render_to_disk),
				 "button_annuler", button_annuler,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(button_annuler);
	GTK_WIDGET_SET_FLAGS(button_annuler, GTK_CAN_DEFAULT);

	gtk_signal_connect(GTK_OBJECT(button_ok), "clicked", GTK_SIGNAL_FUNC(render_to_disk_ok_cb),
			   render_to_disk);
	gtk_signal_connect_object_after(GTK_OBJECT(button_ok), "clicked",
					GTK_SIGNAL_FUNC(gtk_widget_destroy),
					GTK_OBJECT(render_to_disk));
	gtk_signal_connect_object(GTK_OBJECT(button_annuler), "clicked",
				  GTK_SIGNAL_FUNC(render_to_disk_annuler_cb),
				  GTK_OBJECT(render_to_disk));
	gtk_signal_connect_object_after(GTK_OBJECT(button_annuler), "clicked",
					GTK_SIGNAL_FUNC(gtk_widget_destroy),
					GTK_OBJECT(render_to_disk));


	gtk_widget_grab_focus(numberentry_rtd_xres);
	gtk_widget_grab_default(numberentry_rtd_xres);
	gtk_object_set_data(GTK_OBJECT(render_to_disk), "tooltips", tooltips);

	return render_to_disk;
}

GtkWidget *create_propertybox()
{

	GtkWidget *notebook2;
	GtkWidget *vbox2;
	GtkWidget *table2;
	GtkWidget *label9;
	GtkWidget *label10;
	GtkWidget *label11;
	GtkWidget *label12;
	GtkWidget *numberentry_image_width;
	GtkWidget *combo_entry_image_width;
	GtkWidget *numberentry_image_height;
	GtkWidget *combo_entry_image_height;
	GtkWidget *numberentry_nb_iteration_max;
	GtkWidget *combo_entry_nb_iteration_max;
	GtkWidget *numberentry_eject_val;
	GtkWidget *combo_entry_eject_val;
	GtkWidget *label1;
	GtkWidget *vbox3;
	GtkWidget *table3;
	GtkWidget *label13;
	GtkWidget *label14;
	GtkWidget *label15;
	GtkWidget *label16;
	GtkWidget *label17;
	GtkWidget *label18;
	GtkWidget *label19;
	GtkWidget *numberentry_aa;
	GtkWidget *combo_entry_aa;
	GtkWidget *numberentry_xmax;
	GtkWidget *combo_entry_xmax;
	GtkWidget *numberentry_ymin;
	GtkWidget *combo_entry_ymin;
	GtkWidget *numberentry_xmin;
	GtkWidget *combo_entry_xmin;
	GtkWidget *numberentry_ymax;
	GtkWidget *combo_entry_ymax;
	GtkWidget *numberentry_zoom_plus;
	GtkWidget *combo_entry_zoom_plus;
	GtkWidget *numberentry_zoom_moins;
	GtkWidget *combo_entry_zoom_moins;
	GtkWidget *label5;
	GtkTooltips *tooltips;


	tooltips = gtk_tooltips_new();

	propertybox = gnome_property_box_new();
	gtk_widget_set_name(propertybox, "propertybox");
	gtk_object_set_data(GTK_OBJECT(propertybox), "propertybox", propertybox);

	notebook2 = GNOME_PROPERTY_BOX(propertybox)->notebook;
	gtk_widget_set_name(notebook2, "notebook2");
	gtk_object_set_data(GTK_OBJECT(propertybox), "notebook2", notebook2);
	gtk_widget_show(notebook2);

	vbox2 = gtk_vbox_new(FALSE, 0);
	gtk_widget_set_name(vbox2, "vbox2");
	gtk_widget_ref(vbox2);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "vbox2", vbox2,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(vbox2);
	gtk_container_add(GTK_CONTAINER(notebook2), vbox2);

	table2 = gtk_table_new(5, 2, FALSE);
	gtk_widget_set_name(table2, "table2");
	gtk_widget_ref(table2);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "table2", table2,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(table2);
	gtk_box_pack_start(GTK_BOX(vbox2), table2, TRUE, TRUE, 0);

	label9 = gtk_label_new(_("Width : "));
	gtk_widget_set_name(label9, "label9");
	gtk_widget_ref(label9);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label9", label9,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(label9);
	gtk_table_attach(GTK_TABLE(table2), label9, 0, 1, 0, 1, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);
	gtk_label_set_justify(GTK_LABEL(label9), GTK_JUSTIFY_LEFT);

	label10 = gtk_label_new(_("Height : "));
	gtk_widget_set_name(label10, "label10");
	gtk_widget_ref(label10);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label10", label10, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label10);
	gtk_table_attach(GTK_TABLE(table2), label10, 0, 1, 1, 2, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);
	gtk_label_set_justify(GTK_LABEL(label10), GTK_JUSTIFY_LEFT);

	label11 = gtk_label_new(_("Max Iterations : "));
	gtk_widget_set_name(label11, "label11");
	gtk_widget_ref(label11);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label11", label11, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label11);
	gtk_table_attach(GTK_TABLE(table2), label11, 0, 1, 2, 3, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);
	gtk_label_set_justify(GTK_LABEL(label11), GTK_JUSTIFY_LEFT);

	label12 = gtk_label_new(_("Baillout Value : "));
	gtk_widget_set_name(label12, "label12");
	gtk_widget_ref(label12);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label12", label12, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label12);
	gtk_table_attach(GTK_TABLE(table2), label12, 0, 1, 3, 4, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);
	gtk_label_set_justify(GTK_LABEL(label12), GTK_JUSTIFY_LEFT);

	numberentry_image_width = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_image_width, "numberentry_image_width");
	gtk_widget_ref(numberentry_image_width);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_image_width",
				 numberentry_image_width, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_image_width);
	gtk_table_attach(GTK_TABLE(table2), numberentry_image_width, 1, 2, 0, 1, (GtkAttachOptions)
			 (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_image_width =
	    gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_image_width));
	gtk_widget_set_name(combo_entry_image_width, "combo_entry_image_width");
	gtk_widget_ref(combo_entry_image_width);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_image_width",
				 combo_entry_image_width, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_image_width);
	gtk_tooltips_set_tip(tooltips, combo_entry_image_width,
			     _
			     ("This is the width (in pixel) from the image displayed in the window"),
			     NULL);

	numberentry_image_height = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_image_height, "numberentry_image_height");
	gtk_widget_ref(numberentry_image_height);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_image_height",
				 numberentry_image_height, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_image_height);
	gtk_table_attach(GTK_TABLE(table2), numberentry_image_height, 1, 2, 1, 2, (GtkAttachOptions)
			 (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_image_height =
	    gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_image_height));
	gtk_widget_set_name(combo_entry_image_height, "combo_entry_image_height");
	gtk_widget_ref(combo_entry_image_height);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_image_height",
				 combo_entry_image_height, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_image_height);
	gtk_tooltips_set_tip(tooltips, combo_entry_image_height,
			     _
			     ("This is the height (in pixel) from the image displayed in the window"),
			     NULL);

	numberentry_nb_iteration_max = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_nb_iteration_max, "numberentry_nb_iteration_max");
	gtk_widget_ref(numberentry_nb_iteration_max);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_nb_iteration_max",
				 numberentry_nb_iteration_max, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_nb_iteration_max);
	gtk_table_attach(GTK_TABLE(table2), numberentry_nb_iteration_max,
			 1, 2, 2, 3, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			 (GtkAttachOptions) (0), 0, 0);

	combo_entry_nb_iteration_max =
	    gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_nb_iteration_max));
	gtk_widget_set_name(combo_entry_nb_iteration_max, "combo_entry_nb_iteration_max");
	gtk_widget_ref(combo_entry_nb_iteration_max);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_nb_iteration_max",
				 combo_entry_nb_iteration_max, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_nb_iteration_max);
	gtk_tooltips_set_tip(tooltips, combo_entry_nb_iteration_max,
			     _("Maximum number of Iteration"), NULL);

	numberentry_eject_val = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_eject_val, "numberentry_eject_val");
	gtk_widget_ref(numberentry_eject_val);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_eject_val", numberentry_eject_val,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_eject_val);
	gtk_table_attach(GTK_TABLE(table2), numberentry_eject_val, 1, 2, 3, 4, (GtkAttachOptions)
			 (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_eject_val =
	    gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_eject_val));
	gtk_widget_set_name(combo_entry_eject_val, "combo_entry_eject_val");
	gtk_widget_ref(combo_entry_eject_val);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_eject_val", combo_entry_eject_val,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_eject_val);

	label19 = gtk_label_new(_("Antialiasing : "));
	gtk_widget_set_name(label19, "label19");
	gtk_widget_ref(label19);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label19", label19, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label19);
	gtk_table_attach(GTK_TABLE(table2), label19, 0, 1, 4, 5, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	numberentry_aa = gnome_number_entry_new("antialiasing_value", NULL);
	gtk_widget_set_name(numberentry_aa, "numberentry_aa");
	gtk_widget_ref(numberentry_aa);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "numberentry_aa",
				 numberentry_aa, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_aa);
	gtk_table_attach(GTK_TABLE(table2), numberentry_aa, 1, 2, 4, 5,
			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_aa = gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_aa));
	gtk_widget_set_name(combo_entry_aa, "combo_entry_aa");
	gtk_widget_ref(combo_entry_aa);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "combo_entry_aa",
				 combo_entry_aa, (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_aa);
	gtk_tooltips_set_tip(tooltips, combo_entry_aa,
			     _
			     ("0 or 1 : none.\n  >10 : you are crazy.\n 2 or 3 seems to be a good choice for browsing, if you have a powerfull computer."),
			     NULL);

	label1 = gtk_label_new(_("Image"));
	gtk_widget_set_name(label1, "label1");
	gtk_widget_ref(label1);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label1", label1,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(label1);
	gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook2),
				   gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook2), 0), label1);

	vbox3 = gtk_vbox_new(FALSE, 0);
	gtk_widget_set_name(vbox3, "vbox3");
	gtk_widget_ref(vbox3);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "vbox3", vbox3,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(vbox3);
	gtk_container_add(GTK_CONTAINER(notebook2), vbox3);

	table3 = gtk_table_new(6, 2, FALSE);
	gtk_widget_set_name(table3, "table3");
	gtk_widget_ref(table3);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "table3", table3,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(table3);
	gtk_box_pack_start(GTK_BOX(vbox3), table3, TRUE, TRUE, 0);

	label13 = gtk_label_new(_("Upper left (Re) : "));
	gtk_widget_set_name(label13, "label13");
	gtk_widget_ref(label13);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label13", label13, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label13);
	gtk_table_attach(GTK_TABLE(table3), label13, 0, 1, 0, 1, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	label14 = gtk_label_new(_("Upper left  (Im) : "));
	gtk_widget_set_name(label14, "label14");
	gtk_widget_ref(label14);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label14", label14, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label14);
	gtk_table_attach(GTK_TABLE(table3), label14, 0, 1, 1, 2, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	label15 = gtk_label_new(_("Lower right (Re) : "));
	gtk_widget_set_name(label15, "label15");
	gtk_widget_ref(label15);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label15", label15, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label15);
	gtk_table_attach(GTK_TABLE(table3), label15, 0, 1, 2, 3, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	label16 = gtk_label_new(_("Lower right (Im) : "));
	gtk_widget_set_name(label16, "label16");
	gtk_widget_ref(label16);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label16", label16, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label16);
	gtk_table_attach(GTK_TABLE(table3), label16, 0, 1, 3, 4, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	label17 = gtk_label_new(_("Zoom factor + :"));
	gtk_widget_set_name(label17, "label17");
	gtk_widget_ref(label17);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label17", label17, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label17);
	gtk_table_attach(GTK_TABLE(table3), label17, 0, 1, 4, 5, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	label18 = gtk_label_new(_("Zoom factor - :"));
	gtk_widget_set_name(label18, "label18");
	gtk_widget_ref(label18);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label18", label18, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label18);
	gtk_table_attach(GTK_TABLE(table3), label18, 0, 1, 5, 6, (GtkAttachOptions) (0),
			 (GtkAttachOptions) (0), 0, 0);

	numberentry_xmax = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_xmax, "numberentry_xmax");
	gtk_widget_ref(numberentry_xmax);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_xmax", numberentry_xmax,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_xmax);
	gtk_table_attach(GTK_TABLE(table3), numberentry_xmax, 1, 2, 0, 1,
			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_xmax = gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_xmax));
	gtk_widget_set_name(combo_entry_xmax, "combo_entry_xmax");
	gtk_widget_ref(combo_entry_xmax);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_xmax", combo_entry_xmax,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_xmax);

	numberentry_ymin = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_ymin, "numberentry_ymin");
	gtk_widget_ref(numberentry_ymin);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_ymin", numberentry_ymin,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_ymin);
	gtk_table_attach(GTK_TABLE(table3), numberentry_ymin, 1, 2, 1, 2,
			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_ymin = gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_ymin));
	gtk_widget_set_name(combo_entry_ymin, "combo_entry_ymin");
	gtk_widget_ref(combo_entry_ymin);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_ymin", combo_entry_ymin,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_ymin);

	numberentry_xmin = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_xmin, "numberentry_xmin");
	gtk_widget_ref(numberentry_xmin);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_xmin", numberentry_xmin,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_xmin);
	gtk_table_attach(GTK_TABLE(table3), numberentry_xmin, 1, 2, 2, 3,
			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_xmin = gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_xmin));
	gtk_widget_set_name(combo_entry_xmin, "combo_entry_xmin");
	gtk_widget_ref(combo_entry_xmin);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_xmin", combo_entry_xmin,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_xmin);

	numberentry_ymax = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_ymax, "numberentry_ymax");
	gtk_widget_ref(numberentry_ymax);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_ymax", numberentry_ymax,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_ymax);
	gtk_table_attach(GTK_TABLE(table3), numberentry_ymax, 1, 2, 3, 4,
			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_ymax = gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_ymax));
	gtk_widget_set_name(combo_entry_ymax, "combo_entry_ymax");
	gtk_widget_ref(combo_entry_ymax);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_ymax", combo_entry_ymax,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_ymax);

	numberentry_zoom_plus = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_zoom_plus, "numberentry_zoom_plus");
	gtk_widget_ref(numberentry_zoom_plus);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_zoom_plus", numberentry_zoom_plus,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_zoom_plus);
	gtk_table_attach(GTK_TABLE(table3), numberentry_zoom_plus, 1, 2, 4, 5, (GtkAttachOptions)
			 (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_zoom_plus =
	    gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_zoom_plus));
	gtk_widget_set_name(combo_entry_zoom_plus, "combo_entry_zoom_plus");
	gtk_widget_ref(combo_entry_zoom_plus);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_zoom_plus", combo_entry_zoom_plus,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_zoom_plus);

	numberentry_zoom_moins = gnome_number_entry_new(NULL, NULL);
	gtk_widget_set_name(numberentry_zoom_moins, "numberentry_zoom_moins");
	gtk_widget_ref(numberentry_zoom_moins);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "numberentry_zoom_moins", numberentry_zoom_moins,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(numberentry_zoom_moins);
	gtk_table_attach(GTK_TABLE(table3), numberentry_zoom_moins, 1, 2, 5, 6, (GtkAttachOptions)
			 (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	combo_entry_zoom_moins =
	    gnome_number_entry_gtk_entry(GNOME_NUMBER_ENTRY(numberentry_zoom_moins));
	gtk_widget_set_name(combo_entry_zoom_moins, "combo_entry_zoom_moins");
	gtk_widget_ref(combo_entry_zoom_moins);
	gtk_object_set_data_full(GTK_OBJECT(propertybox),
				 "combo_entry_zoom_moins", combo_entry_zoom_moins,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(combo_entry_zoom_moins);

	label5 = gtk_label_new(_("Location"));
	gtk_widget_set_name(label5, "label5");
	gtk_widget_ref(label5);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label5", label5,
				 (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(label5);
	gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook2),
				   gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook2), 1), label5);
/*
	empty_notebook_page = gtk_vbox_new(FALSE, 0);
	gtk_widget_show(empty_notebook_page);
	gtk_container_add(GTK_CONTAINER(notebook2), empty_notebook_page);

	label6 = gtk_label_new(_("3"));
	gtk_widget_set_name(label6, "label6");
	gtk_widget_ref(label6);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label6", label6, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label6);
	gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook2), gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook2), 2), label6);

	empty_notebook_page = gtk_vbox_new(FALSE, 0);
	gtk_widget_show(empty_notebook_page);
	gtk_container_add(GTK_CONTAINER(notebook2), empty_notebook_page);

	label7 = gtk_label_new(_("4"));
	gtk_widget_set_name(label7, "label7");
	gtk_widget_ref(label7);
	gtk_object_set_data_full(GTK_OBJECT(propertybox), "label7", label7, (GtkDestroyNotify)
				 gtk_widget_unref);
	gtk_widget_show(label7);
	gtk_notebook_set_tab_label(GTK_NOTEBOOK(notebook2), gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook2), 3), label7);

*/
	gtk_signal_connect(GTK_OBJECT(propertybox), "apply", GTK_SIGNAL_FUNC(propertybox_apply),
			   NULL);

	gtk_signal_connect(GTK_OBJECT(propertybox), "help", GTK_SIGNAL_FUNC(propertybox_help),
			   NULL);
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_image_width), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_image_height), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_nb_iteration_max), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_eject_val), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_xmin), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_xmax), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_ymin), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_ymax), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_aa), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_zoom_plus), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));
	gtk_signal_connect_object(GTK_OBJECT(combo_entry_zoom_moins), "changed",
				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
				  GTK_OBJECT(propertybox));

	gtk_signal_connect_object(GTK_OBJECT(propertybox), "destroy",
				  GTK_SIGNAL_FUNC(propertybox_destroy), NULL);

	gtk_object_set_data(GTK_OBJECT(propertybox), "tooltips", tooltips);

	gtk_entry_set_text(GTK_ENTRY(combo_entry_image_width),
			   g_strdup_printf("%d", param_current.Xres));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_image_height),
			   g_strdup_printf("%d", param_current.Yres));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_nb_iteration_max),
			   g_strdup_printf("%d", param_current.nbit_max));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_eject_val),
			   g_strdup_printf("%d", param_current.eject_val));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_xmin),
			   g_strdup_printf("%.25f", param_current.xmin));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_ymin),
			   g_strdup_printf("%.25f", param_current.ymin));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_xmax),
			   g_strdup_printf("%.25f", param_current.xmax));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_ymax),
			   g_strdup_printf("%.25f", param_current.ymax));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_aa),
			   g_strdup_printf("%d", param_current.aa_profondeur));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_zoom_plus), g_strdup_printf("%.20f", zoom_plus));
	gtk_entry_set_text(GTK_ENTRY(combo_entry_zoom_moins), g_strdup_printf("%.20f", zoom_moins));


	return propertybox;
}
